.. _numerics:

Numerical methods
===================================

Here we document which numerical methods are applied to solve
the differential equations of the cable cells and mechanisms.

Passive cable
-------------

Integration of the cable equation: implicit Euler via
linearized set of equations and Thomas algorithm.

Mechanisms
----------

Exponential Euler `cnexp`.

Implicit Euler `sparse`.

Euler-Maruyama (explicit Euler) `stochastic`
